@@ -70,7 +70,7 @@ KCDLabel::KCDLabel(const char *name) : KMainWindow(0,name)
 	toolBar()->insertButton( QPixmap(text), OBJECT_TEXT, true, i18n("Insert Text") );
 	toolBar()->insertButton( QPixmap(centrejust), OBJECT_MULTI_TEXT, true, i18n("Insert Multi Line Text") );
 	toolBar()->insertButton( QPixmap(rainbowtext), OBJECT_CURVED_TEXT, true, i18n("Insert Curved Text") );
-	toolBar()->enableMoving(true);
+	toolBar()->setMovingEnabled(true);
 //	enableToolBar();
     QObject::connect( toolBar(), SIGNAL(clicked(int)), this, SLOT(slotToolBarClick(int)) );
     QObject::connect( toolBar(), SIGNAL(moved(BarPosition)), this, SLOT(slotToolBarMoved()));
@@ -1413,7 +1413,7 @@ void KCDLabel::slotBodyLayout()
 /** invoke the help manual */
 void KCDLabel::slotHelpManual()
 {
-	kapp->invokeHTMLHelp("kcdlabel/index.html", "");
+	kapp->invokeHelp();
 }
 
 /** display the correct status info according to selected object */
